@@ -1,6 +1,8 @@
 #ifndef CLEARLOOKS_TYPES_H
 #define CLEARLOOKS_TYPES_H
 
+#include <ge-support.h>
+
 typedef unsigned char boolean;
 typedef unsigned char uint8;
 
@@ -108,13 +110,6 @@ typedef enum
 	CL_WINDOW_EDGE_SOUTH_EAST  
 } ClearlooksWindowEdge;
 
-typedef struct
-{
-	double r;
-	double g;
-	double b;
-} CairoColor;
-
 typedef struct
 {
 	double x;
@@ -139,6 +134,7 @@ typedef struct
 	boolean disabled;
 	boolean focus;
 	boolean is_default;
+	boolean ltr;
 	
 	ClearlooksStateType state_type;
 	
@@ -160,6 +156,8 @@ typedef struct
 {
 	ClearlooksOrientation orientation;
 	ClearlooksProgressBarStyle style;
+	boolean pulsing;
+	float value;
 } ProgressBarParameters;
 
 typedef struct
@@ -229,6 +227,11 @@ typedef struct
 	ClearlooksWindowEdge edge;
 } ResizeGripParameters;
 
+typedef struct
+{
+	int style;
+} MenuBarParameters;
+
 #define CLEARLOOKS_RECTANGLE_SET(rect, _x, _y, _w, _h) rect.x      = _x; \
                                                        rect.y      = _y; \
                                                        rect.width  = _w; \
