@@ -388,7 +388,7 @@ paint_shadow (cairo_t *cr, GtkStyle *style,
 	}
 	else if (shadow_type == GTK_SHADOW_IN || shadow_type == GTK_SHADOW_ETCHED_IN)
 	{
-		// TODO: Find a way to calculate this value (same as shadow out outer line)
+		/*TODO: Find a way to calculate this value (same as shadow out outer line)*/
 		cairo_set_source_rgb (cr, OUTLINE_GRAY);
 		cairo_stroke (cr);
 
@@ -633,77 +633,6 @@ paint_progress_bar (cairo_t *cr, GtkStyle *style, GtkStateType state_type, GtkPr
 	}
 }
 
-static void
-paint_arrow (GdkWindow *window, GdkGC *gc, GtkArrowType arrow_type,
-	     int x, int y, int width, int height)
-{
-    int half_width, half_height;
-    int center_x, center_y;
-
-    if ((width & 1) == 0)
-	width = width - 1;
-    if ((height & 1) == 0)
-	height = height - 1;
-
-    half_width = width / 2;
-    half_height = height / 2;
-
-    center_x = x + half_width;
-    center_y = y + half_height;
-
-    switch (arrow_type)
-    {
-	int i;
-	static int offset[5] = { 0, -1, -2, -3, -4 };
-	static int length[5] = { 0, 2, 4, 6, 8 };
-	static const int size = 4;
-
-    case GTK_ARROW_UP:
-	for (i = 0; i < size; i++)
-	{
-	    gdk_draw_line (window, gc,
-			   center_x + offset[i],
-			   center_y - 2 + i,
-			   center_x + offset[i] + length[i],
-			   center_y - 2 + i);
-	}
-	break;
-
-    case GTK_ARROW_DOWN:
-	for (i = 0; i < size; i++)
-	{
-	    gdk_draw_line (window, gc,
-			   center_x + offset[i],
-			   center_y + 2 - i,
-			   center_x + offset[i] + length[i],
-			   center_y + 2 - i);
-	}
-	break;
-
-    case GTK_ARROW_LEFT:
-	for (i = 0; i < size; i++)
-	{
-	    gdk_draw_line (window, gc,
-			   center_x - 2 + i,
-			   center_y + offset[i],
-			   center_x - 2 + i,
-			   center_y + offset[i] + length[i]);
-	}
-	break;
-
-    case GTK_ARROW_RIGHT:
-	for (i = 0; i < size; i++)
-	{
-	    gdk_draw_line (window, gc,
-			   center_x + 2 - i,
-			   center_y + offset[i],
-			   center_x + 2 - i,
-			   center_y + offset[i] + length[i]);
-	}
-	break;
-    }
-}
-
 /* style functions */
 
 static void
@@ -812,12 +741,17 @@ draw_shadow (GtkStyle *style,
 	     const gchar *detail, gint x, gint y, gint width, gint height)
 {
 	cairo_t *cr;
-	GdkRectangle area2 = {x, y, width, height};
+	GdkRectangle area2;
 	gboolean focused = FALSE;
 
 	CHECK_ARGS
 	SANITIZE_SIZE
 
+	area2.x = x;
+	area2.y = y;
+	area2.width = width;
+	area2.height = height;
+
 	if (widget != 0 && !GTK_WIDGET_IS_SENSITIVE (widget))
 		state_type = GTK_STATE_INSENSITIVE;
 
@@ -827,15 +761,22 @@ draw_shadow (GtkStyle *style,
 	if (widget != NULL && GTK_WIDGET_HAS_FOCUS (widget))
 		focused = TRUE;
 
-	if (widget && (GTK_IS_COMBO (widget->parent) || GTK_IS_COMBO_BOX_ENTRY (widget->parent)))
+	if (widget && (GE_IS_COMBO (widget->parent) || GE_IS_COMBO_BOX_ENTRY (widget->parent)))
 	{
 		GtkWidget *button;
-		width += 2;
+		if (ge_widget_is_ltr (widget))
+			width += 2;
+		else
+		{
+			x -= 3;
+			width += 3;
+		}
+
 		if (area == NULL)
 			area = &area2;
 		g_object_set_data ((GObject*) widget->parent, "entry", widget);
 		button = g_object_get_data ((GObject*) widget->parent, "button");
-		if (GTK_IS_WIDGET (button))
+		if (GE_IS_WIDGET (button))
 			gtk_widget_queue_draw_area (button,  button->allocation.x, button->allocation.y, button->allocation.width,button->allocation.height);
 	}
 	cr = ge_gdk_drawable_to_cairo (window, area);
@@ -863,25 +804,35 @@ draw_box (GtkStyle *style,
 	CHECK_ARGS
 	SANITIZE_SIZE
 
-    if (DETAIL ("spinbutton")) {
-      if (y > (height / 3)) {
-	/* this is a down arrow shadow */
-	y += 2;
-      }
-    }
-
     debug ("draw_box: detail=%s state=%d shadow=%d x=%d y=%d w=%d h=%d\n",
 	    detail, state_type, shadow_type, x, y, width, height);
 
+	if (DETAIL ("spinbutton"))
+	{
+		/* this is a border round spin buttons - we don't want anything here */
+		gtk_style_apply_default_background (style, window, TRUE, state_type, area, x, y, width, height);
+		return;
+	}
+
 	cr = ge_gdk_drawable_to_cairo (window, area);
 
 	/* no pressed state for scollbar buttons yet... */
 	if (DETAIL ("vscrollbar") || DETAIL ("hscrollbar"))
 		shadow_type = GTK_SHADOW_OUT;
 
-	if (DETAIL ("button") || DETAIL ("optionmenu"))
+	if (DETAIL ("button") || DETAIL ("optionmenu") || DETAIL ("spinbutton_down") || DETAIL ("spinbutton_up"))
 	{
-		if (widget && (GTK_IS_COMBO (widget->parent) || GTK_IS_COMBO_BOX_ENTRY (widget->parent)))
+		if (DETAIL ("spinbutton_down") || DETAIL ("spinbutton_up"))
+		{
+			/* add some padding */
+			x++; y++; width -= 2;
+			if (DETAIL ("spinbutton_up")) 
+				height--;
+			else
+				height -= 2;
+		}
+		
+		if (widget && (GE_IS_COMBO (widget->parent) || GE_IS_COMBO_BOX_ENTRY (widget->parent)))
 		{
 			/* Combobox buttons */
 			gboolean focused = FALSE;
@@ -903,12 +854,16 @@ draw_box (GtkStyle *style,
 
 			g_object_set_data ((GObject*) widget->parent, "button", widget);
 
-			paint_entry_shadow (cr, style, state_type, focused, x - 4, y, width + 4, height);
+			if (ge_widget_is_ltr (widget))
+				paint_entry_shadow (cr, style, state_type, focused, x - 4, y, width + 4, height);
+			else
+				paint_entry_shadow (cr, style, state_type, focused, x, y, width + 4, height);
+
 
 			x += 3; y += 3;
 			width -= 6; height -= 6;
 		}
-		if (widget && (GTK_IS_TREE_VIEW (widget->parent)))
+		if (widget && (GE_IS_TREE_VIEW (widget->parent)))
 		{
 			/* Add some extra padding for treeview column buttons */
 			if (state_type == GTK_STATE_INSENSITIVE)
@@ -926,7 +881,7 @@ draw_box (GtkStyle *style,
 	else if (DETAIL ("buttondefault"))
 	{
 		/* draw Default Button marking, but only when sensitive */
-		if (GTK_WIDGET_SENSITIVE (widget))
+		if (widget && GTK_WIDGET_SENSITIVE (widget))
 		{
 			gdk_cairo_set_source_color (cr, &style->bg[GTK_STATE_SELECTED]);
 			cx = x + 0.5; cy = y + 0.5; cw = width - 1.0; ch = height - 1.0;
@@ -961,15 +916,15 @@ draw_box (GtkStyle *style,
 	else if (DETAIL ("bar"))
 	{
 		GtkProgressBarOrientation orientation;
-		if (widget && GTK_IS_PROGRESS_BAR (widget))
+		if (widget && GE_IS_PROGRESS_BAR (widget))
 			orientation = gtk_progress_bar_get_orientation (GTK_PROGRESS_BAR (widget));
 		else
 			orientation = GTK_PROGRESS_LEFT_TO_RIGHT;
 		paint_progress_bar (cr, style, state_type, orientation, x, y, width, height);
 	}
-	else if (DETAIL ("trough") && GTK_IS_SCALE (widget))
+	else if (DETAIL ("trough") && GE_IS_SCALE (widget))
 	{
-		if (GTK_IS_VSCALE (widget))
+		if (GE_IS_VSCALE (widget))
 		{
 			x += 1; width -= 2;
 		}
@@ -979,9 +934,9 @@ draw_box (GtkStyle *style,
 		}
 		paint_button (cr, style, GTK_STATE_NORMAL, GTK_SHADOW_OUT, x, y, width, height);
 	}
-	else if (DETAIL ("trough") && GTK_IS_SCROLLBAR (widget))
+	else if (DETAIL ("trough") && GE_IS_SCROLLBAR (widget))
 	{
-		if (GTK_IS_HSCROLLBAR (widget))
+		if (GE_IS_HSCROLLBAR (widget))
 			paint_scrollbar_trough (cr, style, state_type, GTK_ORIENTATION_HORIZONTAL, x, y, width, height);
 		else
 			paint_scrollbar_trough (cr, style, state_type, GTK_ORIENTATION_VERTICAL, x, y, width, height);
@@ -991,17 +946,20 @@ draw_box (GtkStyle *style,
 		/* fill  */
 		cairo_rectangle (cr, x, y, width, height);
 
-		if (DETAIL ("toolbar") || DETAIL ("menubar") || DETAIL ("vscrollbar") || DETAIL ("hscrollbar") || DETAIL ("handle"))
+		if (DETAIL ("toolbar") || DETAIL ("menubar") || DETAIL ("vscrollbar") || DETAIL ("hscrollbar") || DETAIL ("handlebox") || DETAIL ("dockitem"))
 		{
 			if (shadow_type == GTK_SHADOW_OUT || shadow_type == GTK_SHADOW_ETCHED_OUT)
 			{
 				cairo_pattern_t *crp;
 				CairoColor c1, c2;
+				gdouble shade_v = 0.1;
 
 				crp = cairo_pattern_create_linear (x, y, x, y + height);
 				ge_gdk_color_to_cairo (&style->bg[state_type], &c1);
-				ge_shade_color (&c1, 0.9, &c2);
-				ge_shade_color (&c1, 1.1, &c1);
+				if (DETAIL ("vscrollbar") || DETAIL ("hscrollbar")) 
+					shade_v = 0.3;
+				ge_shade_color (&c1, 1.0 - shade_v, &c2);
+				ge_shade_color (&c1, 1.0 + shade_v, &c1);
 				/*
 				cairo_pattern_add_color_stop_rgb (crp, 0.0, 238/255.0, 238/255.0, 236/255.0);
 				cairo_pattern_add_color_stop_rgb (crp, 1.0, 185/255.0, 189/255.0, 182/255.0);
@@ -1042,117 +1000,104 @@ draw_arrow (GtkStyle *style,
 	    GtkArrowType arrow_type,
 	    gint fill, gint x, gint y, gint width, gint height)
 {
-    //eazel_theme_data *theme_data;
+	cairo_t *cr;
 
-    /* FIXME GNOME2: bad hack added to make arrows draw large enough */
-    width = width + 8;
-    height = height + 6;
-    x = x - 4;
-    y = y - 3;
-
-    CHECK_ARGS
-    /*SANITIZE_SIZE*/
-
-    //theme_data = CRUX_RC_STYLE (style->rc_style)->theme_data;
-    //g_assert (theme_data != NULL);
-
-    debug ("draw_arrow: detail=%s state=%d shadow=%d arrow_type=%d x=%d y=%d w=%d h=%d\n",
+	CHECK_ARGS;
+	debug ("draw_arrow: detail=%s state=%d shadow=%d arrow_type=%d x=%d y=%d w=%d h=%d\n",
 	    detail, state_type, shadow_type, arrow_type, x, y, width, height);
 
-    if (DETAIL ("vscrollbar") || DETAIL ("hscrollbar"))
-    {
-	x++;y++; width--; height--;
-	    /*
-	int type = 0;
-	switch (arrow_type)
+	if (arrow_type == (GtkArrowType)4)/*NONE - new in GTK 2.10*/
+		return;
+
+	if (DETAIL ("vscrollbar") || DETAIL ("hscrollbar"))
 	{
-	case GTK_ARROW_UP:
-	    type = EAZEL_ENGINE_ARROW_UP;
-	    break;
+		/* add some padding */
+		x++; y++; height--; width--; 
+		if (DETAIL ("hscrollbar"))
+			width--;
+		else
+			height--;
 
-	case GTK_ARROW_DOWN:
-	    type = EAZEL_ENGINE_ARROW_DOWN;
-	    break;
-
-	case GTK_ARROW_LEFT:
-	    type = EAZEL_ENGINE_ARROW_LEFT;
-	    break;
-
-	case GTK_ARROW_RIGHT:
-	    type = EAZEL_ENGINE_ARROW_RIGHT;
-	    break;
+		/* random adjustments... */
+		if (arrow_type == GTK_ARROW_DOWN)
+			y++;
+		else if (arrow_type == GTK_ARROW_RIGHT)
+			x++;
+			
 	}
-	*/
-	}
-    if (DETAIL ("spinbutton"))
-    {
-	int window_width, window_height;
-	int tem_x, tem_y;
-
-	if (widget != 0 && !GTK_WIDGET_IS_SENSITIVE (widget))
-	    state_type = GTK_STATE_INSENSITIVE;
-
-	gdk_window_get_size (window, &window_width, &window_height);
-
-	if (state_type != GTK_STATE_INSENSITIVE)
+	else if (DETAIL ("spinbutton"))
 	{
-	    draw_box (style, window, state_type, shadow_type,
-		      area, widget, detail,
-		      x, y - (arrow_type == GTK_ARROW_DOWN),
-		      width, height + 1);
+		if (arrow_type == GTK_ARROW_DOWN)
+			y+=2;
+		else if (arrow_type == GTK_ARROW_UP)
+			y--;
+
+		x++; width--;
+
 	}
-
-	/*
-	  else if (arrow_type == GTK_ARROW_UP)
-	  {
-	  XXX A hack, assumes that up arrow is drawn before
-	  XXX down arrow. (Currently it is)
-
-	  draw_shadow (style, window, GTK_STATE_NORMAL, GTK_SHADOW_OUT,
-	  NULL, widget, "entry", x - 2, 0,
-	  width + 4, window_height);
-	  }
-	*/
-
-	tem_x = x + (width / 2);
-	tem_y = y + (height / 2);
-	if (arrow_type == GTK_ARROW_UP)
+	else if (DETAIL ("menuitem"))
 	{
-	    int i;
-	    tem_y--;
-	    for (i = 0; i < 4; i++)
-	    {
-		gdk_draw_line (window, style->fg_gc[state_type],
-			       tem_x - i, tem_y + i,
-			       tem_x + i, tem_y + i);
-	    }
+		/* make slightly smaller... */
+		x++;
+		height-=2;
+	} else if (ge_is_in_combo_box (widget) || ge_is_combo_box (widget, FALSE))
+	{
+		x+=2; y+=3; width -= 4; height -= 4;
+		if (ge_is_combo (widget))
+			width--;
 	}
 	else
 	{
-	    int i;
-	    tem_y -= 2;
-	    for (i = 0; i < 4; i++)
-	    {
-		gdk_draw_line (window, style->fg_gc[state_type],
-			       tem_x - i, tem_y + (4 - i),
-			       tem_x + i, tem_y + (4 - i));
-	    }
+		/* catch all to add some padding... */
+		x++;
+		y++;
+		width -= 2;
+		height -= 2;
 	}
-	if (state_type != GTK_STATE_INSENSITIVE)
-	{
-	  draw_shadow (style, window, GTK_STATE_NORMAL, GTK_SHADOW_OUT,
-		       NULL, widget, "entry", x - 2, 0,
-		       width + 4, window_height);
-	}
-    }
-    else
-    {
-	if (widget != 0 && !GTK_WIDGET_IS_SENSITIVE (widget))
-	    state_type = GTK_STATE_INSENSITIVE;
 
-	paint_arrow (window, style->fg_gc[state_type],
-		     arrow_type, x, y, width, height);
-    }
+	/* make triangle equilateral */
+	if (arrow_type == GTK_ARROW_UP || arrow_type == GTK_ARROW_DOWN)
+		height = sin (60.0 * 0.017453) * width;
+	else if (arrow_type == GTK_ARROW_LEFT || GTK_ARROW_RIGHT)
+		width = sin (60.0 * 0.017453) * height;
+
+
+	cr = ge_gdk_drawable_to_cairo (window, area);
+
+	switch (arrow_type)
+	{
+		case GTK_ARROW_UP:
+			cairo_move_to (cr, x, y + height);
+			cairo_line_to (cr, x + width, y + height);
+			cairo_line_to (cr, x + (width / 2.0), y);
+			cairo_line_to (cr, x, y + height);
+			break;
+		default:
+		case GTK_ARROW_DOWN:
+			cairo_move_to (cr, x, y);
+			cairo_line_to (cr, x + width, y);
+			cairo_line_to (cr, x + (width / 2.0), y + height);
+			cairo_line_to (cr, x, y);
+			break;
+		case GTK_ARROW_LEFT:
+			cairo_move_to (cr, x + width, y);
+			cairo_line_to (cr, x, y + (height / 2.0));
+			cairo_line_to (cr, x + width, y + height);
+			cairo_line_to (cr, x + width, y);
+			break;
+		case GTK_ARROW_RIGHT:
+			cairo_move_to (cr, x, y);
+			cairo_line_to (cr, x + width, y + (height / 2.0));
+			cairo_line_to (cr, x, y + height);
+			cairo_line_to (cr, x, y);
+			break;
+	}
+
+	gdk_cairo_set_source_color (cr, &style->fg[state_type]);
+	cairo_fill (cr);
+	
+	cairo_destroy (cr);
+
 }
 
 static void
@@ -1182,7 +1127,7 @@ draw_check (GtkStyle *style,
 	ch = height - 1.0; cw = width - 1.0;
 
 
-	if (!GTK_IS_MENU_ITEM (widget))
+	if (!GE_IS_MENU_ITEM (widget))
 	{
 		ge_cairo_rounded_rectangle (cr, cx, cy, cw, ch, 2.0, CR_CORNER_ALL);
 		if (state_type == GTK_STATE_INSENSITIVE)
@@ -1298,7 +1243,7 @@ draw_option (GtkStyle *style,
 	cy = y + (height / 2);
 	radius = (height / 2) - 0.5;
 
-	if (!GTK_IS_MENU_ITEM (widget))
+	if (!GE_IS_MENU_ITEM (widget))
 	{
 		cairo_arc (cr, cx, cy, radius, 0.0, M_PI * 2);
 
@@ -1396,12 +1341,14 @@ draw_tab (GtkStyle *style,
 	/* Draws an option menu tab (the up and down pointing arrows)
 	 * TODO: Make this look neater
 	 */
+    	debug ("draw_tab: detail=%s state=%d shadow=%d x=%d y=%d w=%d h=%d\n",
+	    detail, state_type, shadow_type, x, y, width, height);
 
 	draw_arrow (style, window, state_type, shadow_type, area, widget, detail,
-		    GTK_ARROW_UP, FALSE, x, y - 2, width, height);
+		    GTK_ARROW_UP, FALSE, x + width / 2, y - height / 2, width * 0.66, height);
 
 	draw_arrow (style, window, state_type, shadow_type, area, widget, detail,
-		    GTK_ARROW_DOWN, FALSE, x, y + 3, width, height);
+		    GTK_ARROW_DOWN, FALSE, x + width / 2, y + height / 2 + 1, width * 0.66, height);
 }
 
 static void
@@ -1437,6 +1384,7 @@ draw_shadow_gap (GtkStyle *style,
 	rect.width = gap_width;
 	rect.height = 2;
 	break;
+    default:
     case GTK_POS_BOTTOM:
 	rect.x = x + gap_x;
 	rect.y = y + height - 2;
@@ -1511,26 +1459,27 @@ draw_box_gap (GtkStyle *style,
     case GTK_POS_TOP:
 	rect.x = x + gap_x;
 	rect.y = y;
-	rect.width = gap_width;
+	rect.width = gap_width - 1;
 	rect.height = 2;
 	break;
+    default:
     case GTK_POS_BOTTOM:
 	rect.x = x + gap_x;
 	rect.y = y + height - 2;
-	rect.width = gap_width;
+	rect.width = gap_width - 1;
 	rect.height = 2;
 	break;
     case GTK_POS_LEFT:
 	rect.x = x;
 	rect.y = y + gap_x;
 	rect.width = 2;
-	rect.height = gap_width;
+	rect.height = gap_width - 1;
 	break;
     case GTK_POS_RIGHT:
 	rect.x = x + width - 2;
 	rect.y = y + gap_x;
 	rect.width = 2;
-	rect.height = gap_width;
+	rect.height = gap_width - 1;
 	break;
     }
 
@@ -1549,31 +1498,17 @@ draw_extension (GtkStyle *style,
 		gint x,
 		gint y, gint width, gint height, GtkPositionType gap_side)
 {
-    debug ("draw_extension: detail=%s state=%d shadow=%d x=%d y=%d w=%d h=%d\n",
-	    detail, state_type, shadow_type, x, y, width, height);
-
-	/* Get x relative to parent widget, not window */
-	GtkWidget* parent_widget;
-	gint relative_x;
-	if (widget != NULL &&
-	    (parent_widget = gtk_widget_get_parent(widget)) != NULL)
-	{
-		relative_x = x - parent_widget->allocation.x;
-		if (GTK_IS_CONTAINER(widget))
-			relative_x = relative_x - gtk_container_get_border_width((GtkContainer*)widget);
-	}
-	else
-	{
-		relative_x = x;
-	}
-
 	cairo_t *cr;
 	cairo_pattern_t *crp;
 	CairoColor c1, c2;
 	CairoCorners corners;
 
+	debug ("draw_extension: detail=%s state=%d shadow=%d x=%d y=%d w=%d h=%d\n",
+		detail, state_type, shadow_type, x, y, width, height);
+
 	cr = ge_gdk_drawable_to_cairo (window, area);
 
+	cairo_save (cr); /* save initial clip for later */
 	cairo_rectangle (cr, x, y, width, height);
 	cairo_clip_preserve (cr);
 	cairo_new_path (cr);
@@ -1585,30 +1520,29 @@ draw_extension (GtkStyle *style,
 	{
 		case GTK_POS_TOP:
 			/* bottom tab */
-			y--;
-			y--;
+			y -= style->ythickness;
+			height += style->ythickness;
 			corners = CR_CORNER_BOTTOMLEFT + CR_CORNER_BOTTOMRIGHT;
 			crp = cairo_pattern_create_linear (x, y + height, x, y);
 			ge_shade_color (&c2, 0.8, &c1);
 			break;
+		default:
 		case GTK_POS_BOTTOM:
 			/* top tab */
-			height++;
-			height++;
+			height += style->ythickness;
 			corners = CR_CORNER_TOPLEFT + CR_CORNER_TOPRIGHT;
 			crp = cairo_pattern_create_linear (x, y, x, y + height);
 			break;
 		case GTK_POS_LEFT:
 			/* right tab */
-			x--;
-			x--;
+			x -= style->xthickness;
+			width += style->xthickness;
 			corners = CR_CORNER_TOPRIGHT + CR_CORNER_BOTTOMRIGHT;
 			crp = cairo_pattern_create_linear (x + width, y, x, y);
 			break;
 		case GTK_POS_RIGHT:
 			/* left tab */
-			width++;
-			width++;
+			width += style->xthickness;
 			corners = CR_CORNER_BOTTOMLEFT + CR_CORNER_TOPLEFT;
 			crp = cairo_pattern_create_linear (x, y, x + width, y);
 			break;
@@ -1625,9 +1559,28 @@ draw_extension (GtkStyle *style,
 	cairo_set_source_rgb (cr, OUTLINE_GRAY);
 	cairo_stroke (cr);
 	
+
 	x++; y++; width -= 2.0; height -= 2.0;
+	if (state_type == GTK_STATE_NORMAL)
+	{
+		cairo_restore (cr); /* restore the original clip */
+		switch (gap_side)
+		{
+			case GTK_POS_BOTTOM: height += 2; cairo_rectangle (cr, x, y, width, height -1); break; /* top */
+			case GTK_POS_TOP: y -= 2; height += 2; cairo_rectangle (cr, x, y + 1, width, height - 1); break; /* bottom */
+			case GTK_POS_LEFT: x -= 2; width += 2; cairo_rectangle (cr, x + 1, y, width - 1, height); break; /* right */
+			case GTK_POS_RIGHT: width += 2; cairo_rectangle (cr, x, y, width - 1, height); break; /* left */
+		}
+		
+		cairo_clip_preserve (cr);
+		cairo_new_path (cr);
+	}
+
 	ge_cairo_rounded_rectangle (cr, x + 0.5, y + 0.5, width - 1.0, height - 1.0, 1.0, corners);
-	cairo_set_source_rgba (cr, 1.0, 1.0, 1.0, 0.5); /* must be same colour as corresponding draw_box highlight */
+	if (gap_side == GTK_POS_TOP && state_type == GTK_STATE_NORMAL)
+		cairo_set_source_rgba (cr, 0.0, 0.0, 0.0, 0.2);
+	else
+		cairo_set_source_rgba (cr, 1.0, 1.0, 1.0, 0.5); /* must be same colour as corresponding draw_box highlight */
 	cairo_stroke (cr);
 	cairo_destroy (cr);
 }
@@ -1748,15 +1701,8 @@ draw_handle (GtkStyle *style,
 	state_type = GTK_STATE_ACTIVE;
 
 
-/*
-	cairo_t *cr;
-	cr = ge_gdk_drawable_to_cairo (window, NULL);
-	paint_shadow (cr, style, state_type, GTK_SHADOW_OUT,x, y, width, height);
-	cairo_destroy (cr);
-	*/
-
-
-	draw_box (style, window, state_type, shadow_type, area, widget, detail, x, y, width, height);
+	if (!ge_is_panel_widget_item (widget) && !ge_object_is_a ((GObject*)widget, "PanelToplevel"))
+		draw_box (style, window, state_type, shadow_type, area, widget, detail, x, y, width, height);
 
     light_gc = style->light_gc[state_type];
     dark_gc = style->dark_gc[state_type];
@@ -1776,7 +1722,7 @@ draw_handle (GtkStyle *style,
     if (height > width)
     {
 	yy = y + height / 2 - 4;
-	for (i = 0; i < 9; i += 2)
+	for (i = 0; i < 8; i += 2)
 	{
 	    gdk_draw_line (window, dark_gc, xthick, yy + i,
 			   x + width - xthick, yy + i);
@@ -1786,8 +1732,8 @@ draw_handle (GtkStyle *style,
     }
     else
     {
-	xx = x + width / 2 - 5;
-	for (i = 0; i < 10; i += 4)
+	xx = x + width / 2 - 4;
+	for (i = 0; i < 8; i += 2)
 	{
 	    gdk_draw_line (window, dark_gc, xx + i, ythick,
 			   xx + i, y + height - ythick);
