@@ -517,7 +517,7 @@ draw_slider (GtkStyle      *style,
 	SANITIZE_SIZE
 	
 	/* This makes the slider overlay the stepper buttons at the sides. XXX */
-	if (widget && GTK_IS_SCROLLBAR (widget)) {
+	if (widget && GE_IS_SCROLLBAR (widget)) {
 		GtkAdjustment *adjustment = GTK_RANGE (widget)->adjustment;
 		/* If all of these values are 0, don't do anything.  This fixes mozilla/galeon scrollbars. */
 		if (adjustment->value ||
@@ -583,12 +583,9 @@ real_draw_box (GtkStyle      *style,
 	       gint           height,
 	       gboolean       fill)
 {
-	/* None of the drawing routines below are set up to handle SHADOW_TYPE_NONE,
-	 * so just fill in a blank box here.  Ideally everything in the theme
-	 * would be reworked to handle SHADOW_TYPE_NONE correctly */
-	if (shadow_type == GTK_SHADOW_NONE)
-		return;
-
+	/* For the shadow_type == GTK_SHADOW_NONE case we try to do some magic ...
+	 * Buttons are drawn normally, but without any shadow effects, and most
+	 * important, for unkown stuff we fall back to flat_box. */
 	cairo_save (cr);
 
 	if (CHECK_DETAIL (detail, "button") ||
@@ -605,7 +602,7 @@ real_draw_box (GtkStyle      *style,
 		/* So we don't need to use transparency in the border,
 		 * hack this here. If it doesn't work correctly, it won't
 		 * look too bad. */
-		if (widget && GTK_WIDGET_HAS_DEFAULT (widget))
+		if (widget && GE_WIDGET_HAS_DEFAULT (widget))
 			fg.a = 1;
 		else
 			fg.a = BUTTON_BORDER_OPACITY;
@@ -651,7 +648,7 @@ real_draw_box (GtkStyle      *style,
 		}
 
 		/* Only draw shadow if button is large enough to fit it. */
-		if (width > 18 && height > 18) {
+		if (width > 18 && height > 18 && shadow_type != GTK_SHADOW_NONE) {
 			gint slope = MIN (width / 2, height / 2);
 			CairoColor inner;
 			CairoColor outer;
@@ -822,6 +819,11 @@ real_draw_box (GtkStyle      *style,
 		ge_gdk_color_to_cairo (&style->bg[state_type], &bg);
 		ge_gdk_color_to_cairo (&style->fg[state_type], &bevel);
 		bevel.a = MENUBAR_BORDER_OPACITY;
+		
+		/* ignore the menubar if the shadow is NONE. This is the case for the
+		 * mainmenu applet and the task selector. */
+		if (shadow_type == GTK_SHADOW_NONE)
+			return;
 
 		if (fill)
 			draw_rounded_rect (cr, x, y, width, height, IF_ROUNDED (style, 1.5, 0),
@@ -869,7 +871,7 @@ real_draw_box (GtkStyle      *style,
 		CairoColor bevel, bg;
 		CairoCorners corners = CR_CORNER_ALL;
 
-		if ((IS_SPIN_BUTTON (widget) && CHECK_DETAIL (detail, "entry")) ||
+		if ((GE_IS_SPIN_BUTTON (widget) && CHECK_DETAIL (detail, "entry")) ||
 		    ge_is_in_combo_box (widget)) {
 			/* effectively cut one side off. */
 			width += 2;
@@ -889,12 +891,17 @@ real_draw_box (GtkStyle      *style,
 		ge_gdk_color_to_cairo (&style->fg[state_type], &bevel);
 		bevel.a = STANDARD_BORDER_OPACITY;
 
-		if (fill)
-			draw_rounded_rect (cr, x, y, width, height, IF_ROUNDED (style, 1.5, 0),
-					   &bevel, &bg, corners);
-		else
+		if (fill) {
+			if (shadow_type != GTK_SHADOW_NONE) {
+				draw_rounded_rect (cr, x, y, width, height, IF_ROUNDED (style, 1.5, 0),
+						   &bevel, &bg, corners);
+			} else {
+				parent_class->draw_flat_box (style, window, state_type, shadow_type, area, widget, detail, x, y, width, height);
+			}
+		} else if (shadow_type != GTK_SHADOW_NONE) {
 			draw_rounded_rect (cr, x, y, width, height, IF_ROUNDED (style, 1.5, 0),
 					   &bevel, NULL, corners);
+		}
 	}
 
 	cairo_restore (cr);
@@ -950,7 +957,7 @@ draw_focus (GtkStyle      *style,
 		SANITIZE_SIZE
 		CHECK_ARGS
 
-		if (ge_is_in_combo_box (widget) || IS_SPIN_BUTTON (widget)) {
+		if (ge_is_in_combo_box (widget) || GE_IS_SPIN_BUTTON (widget)) {
 			if (ge_widget_is_ltr (widget))
 				corners = CR_CORNER_TOPLEFT | CR_CORNER_BOTTOMLEFT;
 			else
@@ -1427,8 +1434,16 @@ draw_option (GtkStyle * style,
 			   3 * M_PI_2 + M_PI_4);
 		cairo_close_path (cr);
 		cairo_fill (cr);
+	} else if (shadow_type == GTK_SHADOW_ETCHED_IN) {
+		/* XXX: inconsistent state needs sanity check */
+		cairo_set_line_width (cr, 2.0);
+		cairo_set_line_cap (cr, CAIRO_LINE_CAP_BUTT);
+		cairo_move_to (cr, xc - radius + 2, yc);
+		cairo_line_to (cr, xc + radius - 2, yc);
+
+		cairo_stroke (cr);
 	}
-	/* XXX: inconsistent state missing */
+	cairo_destroy (cr);
 }
 
 static GdkPixbuf*
